/*$Id: s__.cc,v 18.5 2000/07/10 08:36:32 al Exp $ -*- C++ -*-
 * base class for simulation methods
 */
#include "s__.h"

double	SIM::freq = 0.;
COMPLEX	SIM::jomega = 0.;
double	SIM::time0 = 0.;
double	SIM::time1 = 0.;
double	SIM::dtmin = 0.;
double	SIM::temp = 0.;
double	SIM::last_time = 0.;
double	SIM::damp = 1.0;
bool	SIM::uic = false;
bool	SIM::bypass_ok = false;
TRI_STATE SIM::inc_mode = tsNO;
bool	SIM::fulldamp = false;
int	SIM::mode = sNONE;
SIM::PHASE SIM::phase = pNONE;
bool	SIM::freezetime = false;
int*	SIM::nm = NULL;
double*	SIM::i = NULL;
double*	SIM::v0 = NULL;
double*	SIM::vi1 = NULL;
double*	SIM::vt1 = NULL;
double*	SIM::fw = NULL;
double*	SIM::vdc = NULL;
COMPLEX*SIM::ac = NULL;
double	SIM::genout = 0.;
std::deque<CARD*> SIM::evalq1;
std::deque<CARD*> SIM::evalq2;
std::deque<CARD*> SIM::evalq_last;
std::vector<CARD*> SIM::loadq;
std::vector<CARD*> SIM::acceptq;
std::deque<CARD*>* SIM::evalq    = &SIM::evalq1;
std::deque<CARD*>* SIM::evalq_uc = &SIM::evalq2;
